/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.iptc.vocabularies;

import javax.annotation.Nonnull;
import java.util.List;
import java.util.ArrayList;
import java.util.concurrent.CopyOnWriteArrayList;
import java.util.Collection;
import java.io.Serializable;
import it.tidalwave.swing.beansbinding.AbstractBean;

/*******************************************************************************
 *
 * This can'be turned into an interface since NetBeans Matisse requires a
 * concrete JavaBean.
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class IPTCVocabulary extends AbstractBean
  {
    protected final List<Entry> sortedEntries = new ArrayList<Entry>();

    protected final List<String> entries = new ArrayList<String>();
            
    protected transient boolean entriesInitialized;

    @Nonnull
    public List<Entry> getFullEntries() 
      {
        return new CopyOnWriteArrayList<Entry>(sortedEntries);
      }
    
    @Nonnull
    public synchronized Collection<String> getEntries()
      {
        if (!entriesInitialized)
          {
            entriesInitialized = true;
            entries.add(null);
            
            for (final Entry entry : sortedEntries)
              {
                entries.add(entry.getName());
              }
          }
        
        return new CopyOnWriteArrayList<String>(entries);
      }
    
    public static interface Entry extends Serializable
      {
        @Nonnull
        public String getChangeComment();
 
        @Nonnull
        public String getChangeVersion();

        @Nonnull
        public String getDeprecatedVersion();

        @Nonnull
        public String getExplanation();

        @Nonnull
        public String getFirstVersion();

        @Nonnull
        public String getFormalName();

        @Nonnull
        public String getName();
      }
  }
